package com.doc.biz.controller;

import com.alibaba.fastjson2.JSON;
import com.doc.biz.domain.DocInfo;
import com.doc.biz.domain.DocSpace;
import com.doc.biz.domain.EsDocInfo;
import com.doc.biz.service.IDocInfoService;
import com.doc.biz.service.IDocSpaceService;
import com.doc.biz.service.IEsDocInfoService;
import com.doc.common.config.EsConfig;
import com.doc.common.enums.SpaceType;
import com.doc.common.utils.SecurityUtils;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.elasticsearch.core.ElasticsearchRestTemplate;
import org.springframework.data.elasticsearch.core.SearchHit;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * es查询控制器
 *
 * @author wukai
 */
@RestController
@RequestMapping("es")
public class ElasticSearchController {

    @Resource
    private IEsDocInfoService esDocInfoService;
    @Resource
    private IDocInfoService infoService;
    @Resource
    private EsConfig esConfig;
    @Resource
    private IDocSpaceService docSpaceService;


    /**
     * 模糊查询ik分词器分词的content字段
     *
     * @return
     */
    @GetMapping("/query")
    public String query(@RequestParam(value = "type", required = true) String type, @RequestParam(value = "content", required = true) String content, @RequestParam(value = "page") int page, @RequestParam(value = "size") int size) {
        DocSpace space = new DocSpace();
        space.setSpaceType(type);

        if (type.equals(SpaceType.DEPT.getValue())) {
            space.setOwner(SecurityUtils.getDeptId());
        } else if (type.equals(SpaceType.PERSONAL.getValue())) {
            space.setOwner(SecurityUtils.getUserId());
        }
        List<DocSpace> list = docSpaceService.selectDocSpaceList(space);
        if (list.size() > 0) {
            String indexName = "docs_" + list.get(0).getSpaceId();
            esConfig.setIndexName(indexName);
            try {
                List<SearchHit<EsDocInfo>> all = esDocInfoService.findByContent(content, PageRequest.of(page, size));
                for (SearchHit<EsDocInfo> re : all) {
                    EsDocInfo esDocInfo = re.getContent();
                    DocInfo docInfo = new DocInfo();
                    docInfo.setDocId(esDocInfo.getId());
                    docInfo = infoService.selectDocInfoByDocId(esDocInfo.getId());
                    esDocInfo.setDocInfo(docInfo);
                }
                return JSON.toJSONString(all);
            } catch (Exception e) {
                e.printStackTrace();
                return null;
            }
        } else {
            return null;
        }
    }

}